changeset 77305:40f74d56a5f0

Fix typo: "threshhold" -> "threshold".
author Glenn Morris <rgm@gnu.org>
date Thu, 19 Apr 2007 06:30:26 +0000
parents 87a0fb84d1df
children 3932655c7057
files lisp/calendar/todo-mode.el
diffstat 1 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/calendar/todo-mode.el	Thu Apr 19 06:10:34 2007 +0000
+++ b/lisp/calendar/todo-mode.el	Thu Apr 19 06:30:26 2007 +0000
@@ -205,11 +205,11 @@
 ;;     	by the binary insertion algorithm.  However, you may not
 ;;     	really have a need for such accurate priorities amongst your
 ;;     	TODO items.  If you now think about the binary insertion
 ;;     	halfing the size of the window each time, then the threshhold
 ;;     	is the window size at which it will stop.  If you set the
 ;;     	threshhold to zero, the upper and lower bound will coincide at
 ;;     	the end of the loop and you will insert your item just before
 ;;     	that point.  If you set the threshhold to, e.g. 8, it will stop
 ;;     	as soon as the window size drops below that amount and will
 ;;     	insert the item in the approximate centre of that window.  I
 ;;     	got the idea for this feature after reading a very helpful
@@ -307,10 +307,10 @@
 questions by the binary insertion algorithm.  However, you may not
 really have a need for such accurate priorities amongst your TODO
 items.  If you now think about the binary insertion halfing the size
-of the window each time, then the threshhold is the window size at
-which it will stop.  If you set the threshhold to zero, the upper and
+of the window each time, then the threshold is the window size at
+which it will stop.  If you set the threshold to zero, the upper and
 lower bound will coincide at the end of the loop and you will insert
-your item just before that point.  If you set the threshhold to,
+your item just before that point.  If you set the threshold to,
 e.g. 8, it will stop as soon as the window size drops below that
 amount and will insert the item in the approximate center of that
 window."
@@ -205,11 +205,11 @@
 ;;     	really have a need for such accurate priorities amongst your
 ;;     	TODO items.  If you now think about the binary insertion
-;;     	halfing the size of the window each time, then the threshhold
+;;     	halfing the size of the window each time, then the threshold
 ;;     	is the window size at which it will stop.  If you set the
@@ -205,11 +205,11 @@
 ;;     	is the window size at which it will stop.  If you set the
-;;     	threshhold to zero, the upper and lower bound will coincide at
+;;     	threshold to zero, the upper and lower bound will coincide at
 ;;     	the end of the loop and you will insert your item just before
@@ -205,11 +205,11 @@
 ;;     	the end of the loop and you will insert your item just before
-;;     	that point.  If you set the threshhold to, e.g. 8, it will stop
+;;     	that point.  If you set the threshold to, e.g. 8, it will stop
 ;;     	as soon as the window size drops below that amount and will
 ;;     	insert the item in the approximate centre of that window.  I